@@ -55,6 +55,7 @@ def cli_node():
     """Subcommand `vnode`."""
     pass
 
+
 #
 #   list
 #
@@ -113,6 +114,7 @@ def cli_node_list():
         warning(
              f"{Fore.RED}Failed imports: {len(f1)+len(f2)}{Style.RESET_ALL}")
 
+
 #
 #   new
 #
@@ -164,6 +166,7 @@ def cli_node_new_configuration(name, environment, system_folders):
     info(f"You can start the node by running "
          f"{Fore.GREEN}vnode start {flag}{Style.RESET_ALL}")
 
+
 #
 #   files
 #
@@ -200,8 +203,7 @@ def cli_node_files(name, environment, system_folders):
     info(f"Configuration file = {ctx.config_file}")
     info(f"Log file           = {ctx.log_file}")
     info(f"data folders       = {ctx.data_dir}")
-    info(f"Database labels and files")
-
+    info("Database labels and files")
     for label, path in ctx.databases.items():
         info(f" - {label:15} = {path}")
 
@@ -213,6 +215,8 @@ help_ = {
     'config': 'absolute path to configuration-file; overrides NAME',
     'environment': 'configuration environment to use',
 }
+
+
 @cli_node.command(name='start')
 @click.option("-n", "--name", default=None, help="configuration name")
 @click.option("-c", "--config", default=None, help=help_['config'])
@@ -222,12 +226,15 @@ help_ = {
 @click.option('-i', '--image', default=None, help="Node Docker image to use")
 @click.option('--keep/--auto-remove', default=False,
               help="Keep image after finishing")
+@click.option('--force-db-mount', is_flag=True,
+              help="Skip the check of the existence of the DB (always try to "
+                   "mount)")
 @click.option('--attach/--detach', default=False,
               help="Attach node logs to the console after start")
 @click.option('--mount-src', default='',
               help="mount vantage6-master package source")
 def cli_node_start(name, config, environment, system_folders, image, keep,
-                   mount_src, attach):
+                   mount_src, attach, force_db_mount):
     """Start the node instance.
 
         If no name or config is specified the default.yaml configuation is
@@ -254,9 +261,9 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
 
         # check that config exists, if not a questionaire will be invoked
         if not NodeContext.config_exists(name, environment, system_folders):
-            question = f"Configuration '{name}' using environment"
-            question += f" '{environment}' does not exist.\n  Do you want to"
-            question += f" create this config now?"
+            question = (f"Configuration '{name}' using environment "
+                        "'{environment}' does not exist.\n  Do you want to "
+                        "create this config now?")
 
             if q.confirm(question).ask():
                 configuration_wizard("node", name, environment, system_folders)
@@ -265,7 +272,6 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
                 error("Config file couldn't be loaded")
                 sys.exit(0)
 
-
         ctx = NodeContext(name, environment, system_folders)
 
     # check that this node is not already running
@@ -317,7 +323,6 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
         ("/var/run/docker.sock", "/var/run/docker.sock"),
     ]
 
-
     if mount_src:
         # If mount_src is a relative path, docker will consider it a volume.
         mount_src = os.path.abspath(mount_src)
@@ -353,22 +358,32 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
     }
 
     # only mount the DB if it is a file
-    info("Setting up database")
-    db_is_file = Path(ctx.databases["default"]).exists()
-    env['DATABASE_URI'] = "/mnt/database.csv" if db_is_file else \
-        ctx.databases['default']
-    info(f" - URI: {env['DATABASE_URI']}")
-    if db_is_file:
-        mounts.append(("/mnt/database.csv", str(ctx.databases["default"])))
-    else:
-        warning(' - Are you using a non file-based database?')
-        warning('   Or did you make a mistake in the database path?')
+    info("Setting up databases")
+    db_labels = ctx.databases.keys()
+    for label in db_labels:
+
+        uri = ctx.databases[label]
+        info(f"  Processing database '{label}:{uri}'")
+        LABEL = label.upper()
+
+        file_based = Path(uri).exists()
+        if not file_based and not force_db_mount:
+            debug('  - non file-based database added')
+            env[f'{LABEL}_DATABASE_URI'] = uri
+        else:
+            debug('  - file-based database added')
+            env[f'{LABEL}_DATABASE_URI'] = f'/mnt/{label}.csv'
+            mounts.append((f'/mnt/{label}.csv', str(uri)))
+
+        # FIXME legacy to support < 2.1.3 can be removed from 3+
+        if label == 'default':
+            env['DATABASE_URI'] = '/mnt/default.csv'
 
     system_folders_option = "--system" if system_folders else "--user"
     cmd = f'vnode-local start -c /mnt/config/{name}.yaml -n {name} -e '\
           f'{environment} --dockerized {system_folders_option}'
 
-    info(f"Runing Docker container")
+    info("Running Docker container")
     volumes = {}
     for mount in mounts:
         volumes[mount[1]] = {'bind': mount[0], 'mode': 'rw'}
@@ -405,6 +420,7 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
                 info("Closing log file. Keyboard Interrupt.")
                 exit(0)
 
+
 #
 #   stop
 #
@@ -444,7 +460,9 @@ def cli_node_stop(name, system_folders, all_nodes):
 
         if name in running_node_names:
             container = client.containers.get(name)
-            container.kill()
+            # Stop the container. Using stop() gives the container 10s to exit
+            # itself, if not then it will be killed
+            container.stop()
             info(f"Stopped the {Fore.GREEN}{name}{Style.RESET_ALL} Node.")
         else:
             error(f"{Fore.RED}{name}{Style.RESET_ALL} is not running?")
@@ -541,8 +559,8 @@ def cli_node_create_private_key(name, environment, system_folders, upload,
     if file_.exists() and not overwrite:
         error("Could not create private key!")
         warning(
-            f"If you're **sure** you want to create a new key, "
-            f"please run this command with the '--overwrite' flag"
+            "If you're **sure** you want to create a new key, "
+            "please run this command with the '--overwrite' flag"
         )
         warning("Continuing with existing key instead!")
         private_key = RSACryptor(file_).private_key
@@ -621,7 +639,7 @@ def cli_node_clean():
             msg += volume.name + ","
     info(msg)
 
-    confirm = q.confirm(f"Are you sure?")
+    confirm = q.confirm("Are you sure?")
     if confirm.ask():
         for volume in canditates:
             try:
@@ -661,8 +679,9 @@ def cli_node_version(name, system_folders):
 
     if name in running_node_names:
         container = client.containers.get(name)
-        version = container.exec_run(cmd='vnode-local version', stdout = True)
-        click.echo({"node": version.output.decode('utf-8'), "cli":__version__})
+        version = container.exec_run(cmd='vnode-local version', stdout=True)
+        click.echo({"node": version.output.decode('utf-8'),
+                    "cli": __version__})
 
 
 def print_log_worker(logs_stream):
